(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22791,        680]
NotebookOptionsPosition[     21474,        630]
NotebookOutlinePosition[     21831,        646]
CellTagsIndexPosition[     21788,        643]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[Cell["\<\
This file contains the derivations for Appendix B for the steady state \
without scale effects. 
For corresponding notations in the main text, L represents lambda, f \
represents varphi, p represents phi, g represents rho, u represents mu, a \
represents alpha, b represents sigma, and x represents E.\
\>"]], "Input",
 CellChangeTimes->{{3.594100308233206*^9, 3.59410032843465*^9}, {
   3.596517062223633*^9, 3.596517066484461*^9}, 3.6209664537665124`*^9, {
   3.620966540264711*^9, 3.620966670503874*^9}, {3.620966982379381*^9, 
   3.620966997979721*^9}, {3.6209674634923687`*^9, 3.620967464226856*^9}, {
   3.6209681029108677`*^9, 3.6209681041747026`*^9}, {3.620969452179845*^9, 
   3.6209694829000826`*^9}}],

Cell[BoxData[Cell["Solve for equation (B.1) for R."]], "Input",
 CellChangeTimes->{{3.594100308233206*^9, 3.59410032843465*^9}, {
   3.596517062223633*^9, 3.596517066484461*^9}, 3.6209664537665124`*^9, {
   3.620966540264711*^9, 3.620966670503874*^9}, {3.620966982379381*^9, 
   3.620966997979721*^9}, {3.6209674634923687`*^9, 3.620967464226856*^9}, {
   3.6209681029108677`*^9, 3.6209681041747026`*^9}, {3.6209682231630664`*^9, 
   3.620968240717039*^9}, {3.620968513082822*^9, 3.620968519946384*^9}, {
   3.6209692648260393`*^9, 3.620969278786319*^9}, {3.6424788530873528`*^9, 
   3.6424788559005566`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "s"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"R", "-", "n", "+", "L"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"s", "*", "L"}], ")"}], "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"R", "-", "n", "+", "L"}], ")"}], "^", "2"}]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "-", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"a", "*", "u"}], ")"}]}], "-", "p"}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"L", "*", "t", "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"1", "/", "u"}]}], ")"}]}], ")"}]}]}], ",", "R"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.616819429042646*^9, 3.61681949158442*^9}, {
  3.6168195265435796`*^9, 3.616819590202717*^9}, {3.616819922014841*^9, 
  3.6168199240692015`*^9}, {3.6168202094134836`*^9, 3.616820219185953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"R", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
        RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
           RowBox[{"2", " ", "b", " ", 
            RowBox[{"(", 
             RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "-", 
        SqrtBox[
         RowBox[{"a", " ", 
          SuperscriptBox["L", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
               RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}],
        ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"a", " ", "u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"R", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
        RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
           RowBox[{"2", " ", "b", " ", 
            RowBox[{"(", 
             RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          SuperscriptBox["L", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
               RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}],
        ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"a", " ", "u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6168195806874175`*^9, 3.6168196035035253`*^9}, 
   3.6168199685736675`*^9, 3.616820232698901*^9, 3.6168488488667517`*^9, 
   3.6201223341883917`*^9}]
}, Open  ]],

Cell[BoxData[Cell["Denote the roots of (B.1) as R1 and R2, which are \
identical."]], "Input",
 CellChangeTimes->{{3.594100308233206*^9, 3.59410032843465*^9}, {
   3.596517062223633*^9, 3.596517066484461*^9}, 3.6209664537665124`*^9, {
   3.620966540264711*^9, 3.620966670503874*^9}, {3.620966982379381*^9, 
   3.620966997979721*^9}, {3.6209674634923687`*^9, 3.620967464226856*^9}, {
   3.6209681029108677`*^9, 3.6209681041747026`*^9}, {3.6209682231630664`*^9, 
   3.620968240717039*^9}, {3.620968513082822*^9, 3.620968519946384*^9}, {
   3.6209692648260393`*^9, 3.6209693160741453`*^9}, {3.64247885830031*^9, 
   3.642478860427724*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
      RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "-", 
      SqrtBox[
       RowBox[{"a", " ", 
        SuperscriptBox["L", "2"], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
             RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"a", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.616819640663714*^9, 3.616819643249412*^9}, 
   3.616820015108532*^9, {3.616820255030692*^9, 3.6168202782390532`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
    RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "-", 
    SqrtBox[
     RowBox[{"a", " ", 
      SuperscriptBox["L", "2"], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
           RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"a", " ", "u", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6168196441750245`*^9, 3.6168200161052003`*^9, {3.616820263878545*^9, 
   3.6168202790826263`*^9}, 3.616848852730318*^9, 3.620122336360832*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
      RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"L", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
      SqrtBox[
       RowBox[{"a", " ", 
        SuperscriptBox["L", "2"], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
             RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"a", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6168196473231163`*^9, 3.616819653673328*^9}, 
   3.6168200297732396`*^9, {3.616820283135295*^9, 3.6168202895265265`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "b", " ", "L", " ", "x"}], "+", 
    RowBox[{"2", " ", "b", " ", "n", " ", "x"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "n"}], ")"}], " ", "u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{"a", " ", 
      SuperscriptBox["L", "2"], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "b", " ", "s", " ", "x"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "s"}], ")"}], "2"], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", "x"}], "-", 
           RowBox[{"4", " ", "b", " ", "s", " ", "u", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]]}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"a", " ", "u", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"p", " ", "x"}]}], ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.616819658446477*^9, 3.6168200307799077`*^9, 
  3.6168202903100605`*^9, 3.6168488560254917`*^9, 3.620122339127668*^9}]
}, Open  ]],

Cell[BoxData[Cell["\<\
The following three equations show that when E approches 0, R becomes \
negative.\
\>"]], "Input",
 CellChangeTimes->{{3.594100308233206*^9, 3.59410032843465*^9}, {
   3.596517062223633*^9, 3.596517066484461*^9}, 3.6209664537665124`*^9, {
   3.620966540264711*^9, 3.620966670503874*^9}, {3.620966982379381*^9, 
   3.620966997979721*^9}, {3.6209674634923687`*^9, 3.620967464226856*^9}, {
   3.6209681029108677`*^9, 3.6209681041747026`*^9}, {3.6209682231630664`*^9, 
   3.620968240717039*^9}, {3.620968513082822*^9, 3.620968519946384*^9}, {
   3.6209692648260393`*^9, 3.6209693563780456`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", "0"}]], "Input",
 CellChangeTimes->{{3.620122345192705*^9, 3.620122346736715*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.620122347457199*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "R1", "]"}]], "Input",
 CellChangeTimes->{{3.6201223484248405`*^9, 3.6201223522263613`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "L"}], "+", "n"}]], "Output",
 CellChangeTimes->{3.620122352666648*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "R2", "]"}]], "Input",
 CellChangeTimes->{{3.620122353833436*^9, 3.620122356762364*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "L"}], "+", "n"}]], "Output",
 CellChangeTimes->{3.6201223571616344`*^9}]
}, Open  ]],

Cell[BoxData[Cell["\<\
Solve for E, which is stationary. The two roots are identical.\
\>"]], "Input",
 CellChangeTimes->{{3.594100308233206*^9, 3.59410032843465*^9}, {
   3.596517062223633*^9, 3.596517066484461*^9}, 3.6209664537665124`*^9, {
   3.620966540264711*^9, 3.620966670503874*^9}, {3.620966982379381*^9, 
   3.620966997979721*^9}, {3.6209674634923687`*^9, 3.620967464226856*^9}, {
   3.6209681029108677`*^9, 3.6209681041747026`*^9}, {3.6209682231630664`*^9, 
   3.620968240717039*^9}, {3.620968513082822*^9, 3.620968519946384*^9}, {
   3.6209692648260393`*^9, 3.620969409081215*^9}, {3.685664046100706*^9, 
   3.6856640631059947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"R1", "==", "g"}], ",", "x"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.616820067548247*^9, 3.616820084199272*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "+", "L", "-", "n"}], ")"}], "2"], " ", "u"}], 
     RowBox[{
      RowBox[{"a", " ", "L", " ", 
       RowBox[{"(", 
        RowBox[{"g", "+", "L", "+", 
         RowBox[{"n", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], ")"}]}], "-", 
         RowBox[{"g", " ", "s"}]}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "u"}], ")"}]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"g", "+", "L", "-", "n"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"a", " ", "p", " ", "u"}]}], ")"}]}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6168200868920546`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"R2", "==", "g"}], ",", "x"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.616820096638507*^9, 3.6168200968536644`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "+", "L", "-", "n"}], ")"}], "2"], " ", "u"}], 
     RowBox[{
      RowBox[{"a", " ", "L", " ", 
       RowBox[{"(", 
        RowBox[{"g", "+", "L", "+", 
         RowBox[{"n", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "s"}], ")"}]}], "-", 
         RowBox[{"g", " ", "s"}]}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "u"}], ")"}]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"g", "+", "L", "-", "n"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"a", " ", "p", " ", "u"}]}], ")"}]}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.616820097919369*^9}]
}, Open  ]]
},
WindowSize->{1280, 717},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (2016\:5e742\:670825\
\:65e5)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 734, 12, 72, "Input"],
Cell[1294, 34, 608, 8, 31, "Input"],
Cell[CellGroupData[{
Cell[1927, 46, 1161, 34, 48, "Input"],
Cell[3091, 82, 4602, 129, 130, "Output"]
}, Open  ]],
Cell[7708, 214, 636, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[8369, 227, 2234, 64, 113, "Input"],
Cell[10606, 293, 2078, 62, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12721, 360, 2238, 64, 113, "Input"],
Cell[14962, 426, 2050, 61, 65, "Output"]
}, Open  ]],
Cell[17027, 490, 614, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[17666, 504, 115, 2, 31, "Input"],
Cell[17784, 508, 70, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17891, 514, 136, 2, 48, "Input"],
Cell[18030, 518, 110, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18177, 526, 132, 2, 48, "Input"],
Cell[18312, 530, 112, 3, 31, "Output"]
}, Open  ]],
Cell[18439, 536, 645, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[19109, 550, 214, 5, 48, "Input"],
Cell[19326, 557, 939, 29, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20302, 591, 216, 5, 48, "Input"],
Cell[20521, 598, 937, 29, 52, "Output"]
}, Open  ]]
}
]
*)

